# Generated by Django 3.2.15 on 2023-03-28 14:30

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('invitations', '0003_auto_20151126_1523'),
    ]

    operations = [
        migrations.AlterField(
            model_name='invitation',
            name='id',
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='invitation',
            name='inviter',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='inviter'),
        ),
    ]



# Configuration file for the Sphinx documentation builder.
#
# This file only contains a selection of the most common options. For a full
# list see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html
from __future__ import annotations

import sys
from pathlib import Path

import tomlkit

# -- Path setup --------------------------------------------------------------

here = Path(__file__).parent.resolve()
sys.path.insert(0, str(here / ".."))

# -- Project information -----------------------------------------------------


def _get_project_meta():
    with open("../pyproject.toml") as pyproject:
        file_contents = pyproject.read()

    return tomlkit.parse(file_contents)["tool"]["poetry"]


pkg_meta = _get_project_meta()
project = str(pkg_meta["name"])
copyright = "-"
author = "-"

# The short X.Y version
version = str(pkg_meta["version"])
# The full version, including alpha/beta/rc tags
release = version

# -- General configuration ---------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = [
    "sphinx.ext.autodoc",
    "sphinx.ext.intersphinx",
    "sphinx.ext.viewcode",
]

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
exclude_patterns = [
    "_build",
    "venv",
]

# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = "furo"

# -- Options for LaTeX output ------------------------------------------

# Grouping the document tree into LaTeX files. List of tuples
# (source start file, target name, title, author, documentclass
# [howto/manual]).
latex_documents = [
    (
        "index",
        "django-invitations.tex",
        "django-invitations Documentation",
        "Jazzband",
        "manual",
    ),
]

# -- Options for Intersphinx -------------------------------------------

intersphinx_mapping = {
    "django": (
        "https://docs.djangoproject.com/en/stable/",
        "https://docs.djangoproject.com/en/stable/_objects/",
    ),
}



import datetime

import pytest
from django.contrib.auth import get_user_model
from django.utils import timezone
from freezegun import freeze_time

from invitations.app_settings import app_settings
from invitations.utils import get_invitation_model

Invitation = get_invitation_model()


@pytest.fixture
def invitation_a(db):
    freezer = freeze_time("2015-07-30 12:00:06")
    freezer.start()
    inivitation = Invitation.create("email@example.com")
    freezer.stop()
    return inivitation


@pytest.fixture
def invitation_b(db):
    return Invitation.create("invited@example.com")


@pytest.fixture
def user_a(db):
    return get_user_model().objects.create_user(username="flibble", password="password")


@pytest.fixture
def user_b(db):
    return get_user_model().objects.create_user(
        username="flobble",
        password="password",
        email="flobble@example.com",
    )


@pytest.fixture
def super_user(db):
    return get_user_model().objects.create_superuser(
        username="flibble",
        password="password",
        email="mrflibble@example.com",
    )


@pytest.fixture
def sent_invitation_by_user_a(db, user_a):
    invite = Invitation.create("email@example.com", inviter=user_a)
    invite.sent = timezone.now()
    invite.save()
    return invite


@pytest.fixture
def accepted_invitation(db, user_a):
    invite = Invitation.create("accepted@example.com", inviter=user_a)
    invite.sent = timezone.now()
    invite.accepted = True
    invite.save()
    return invite


@pytest.fixture
def pending_invitation(db, user_a):
    invite = Invitation.create("pending@example.com", inviter=user_a)
    invite.sent = timezone.now() - datetime.timedelta(
        days=app_settings.INVITATION_EXPIRY - 1,
    )
    invite.save()
    return invite


@pytest.fixture
def expired_invitation(db, user_a):
    invite = Invitation.create("expired@example.com")
    invite.sent = timezone.now() - datetime.timedelta(
        days=app_settings.INVITATION_EXPIRY + 1,
    )
    invite.save()
    return invite



from invitations.app_settings import app_settings

try:
    from django.urls import reverse
except ImportError:
    from django.core.urlresolvers import reverse

import pytest
from allauth.account.models import EmailAddress
from django.test import Client
from django.test.client import RequestFactory

from invitations.adapters import get_invitations_adapter
from invitations.models import InvitationsAdapter
from invitations.utils import get_invitation_model

Invitation = get_invitation_model()


class TestAllAuthIntegrationAcceptAfterSignup:
    client = Client()
    adapter = get_invitations_adapter()

    @pytest.mark.parametrize(
        "method",
        [
            ("get"),
            ("post"),
        ],
    )
    def test_accept_invite_accepted_invitation_after_signup(
        self,
        settings,
        method,
        sent_invitation_by_user_a,
        user_a,
    ):
        settings.INVITATIONS_ACCEPT_INVITE_AFTER_SIGNUP = True
        client_with_method = getattr(self.client, method)
        resp = client_with_method(
            reverse(
                app_settings.CONFIRMATION_URL_NAME,
                kwargs={"key": sent_invitation_by_user_a.key},
            ),
            follow=True,
        )
        assert resp.status_code == 200

        invite = Invitation.objects.get(email="email@example.com")
        assert invite.inviter == user_a
        assert invite.accepted is False
        assert resp.request["PATH_INFO"] == reverse("account_signup")
        form = resp.context_data["form"]
        assert "email@example.com" == form.fields["email"].initial

        resp = self.client.post(
            reverse("account_signup"),
            {
                "email": "email@example.com",
                "username": "username",
                "password1": "password",
                "password2": "password",
            },
        )
        invite = Invitation.objects.get(email="email@example.com")
        assert invite.accepted is True

    @pytest.mark.parametrize(
        "method",
        [
            ("get"),
            ("post"),
        ],
    )
    def test_invite_accepted_after_signup_with_altered_case_email(
        self,
        settings,
        method,
        sent_invitation_by_user_a,
        user_a,
    ):
        settings.INVITATIONS_ACCEPT_INVITE_AFTER_SIGNUP = True
        client_with_method = getattr(self.client, method)
        resp = client_with_method(
            reverse(
                app_settings.CONFIRMATION_URL_NAME,
                kwargs={"key": sent_invitation_by_user_a.key},
            ),
            follow=True,
        )

        invite = Invitation.objects.get(email="email@example.com")
        assert invite.accepted is False
        form = resp.context_data["form"]
        assert "email@example.com" == form.fields["email"].initial

        resp = self.client.post(
            reverse("account_signup"),
            {
                "email": "EMAIL@EXAMPLE.COM",
                "username": "username",
                "password1": "password",
                "password2": "password",
            },
        )
        invite = Invitation.objects.get(email="email@example.com")
        assert invite.accepted is True


class TestAllAuthIntegration:
    client = Client()
    adapter = get_invitations_adapter()

    @pytest.mark.parametrize(
        "method",
        [
            ("get"),
            ("post"),
        ],
    )
    def test_accept_invite_allauth(
        self,
        method,
        settings,
        user_a,
        sent_invitation_by_user_a,
    ):
        client_with_method = getattr(self.client, method)
        resp = client_with_method(
            reverse(
                app_settings.CONFIRMATION_URL_NAME,
                kwargs={"key": sent_invitation_by_user_a.key},
            ),
            follow=True,
        )
        invite = Invitation.objects.get(email="email@example.com")
        assert invite.accepted
        assert invite.inviter == user_a
        assert resp.request["PATH_INFO"] == reverse("account_signup")

        form = resp.context_data["form"]
        assert "email@example.com" == form.fields["email"].initial
        messages = resp.context["messages"]
        message_text = [message.message for message in messages]
        assert "Invitation to - email@example.com - has been accepted" in message_text

        resp = self.client.post(
            reverse("account_signup"),
            {
                "email": "email@example.com",
                "username": "username",
                "password1": "password",
                "password2": "password",
            },
        )

        allauth_email_obj = EmailAddress.objects.get(email="email@example.com")
        assert allauth_email_obj.verified is True

    def test_fetch_adapter(self):
        assert isinstance(self.adapter, InvitationsAdapter)

    def test_allauth_signup_open(self):
        signup_request = RequestFactory().get(
            reverse("account_signup", urlconf="allauth.account.urls"),
        )
        assert self.adapter.is_open_for_signup(signup_request) is True

    @pytest.mark.django_db
    def test_allauth_adapter_invitations_only(self, settings):
        settings.INVITATIONS_INVITATION_ONLY = True
        signup_request = RequestFactory().get(
            reverse("account_signup", urlconf="allauth.account.urls"),
        )
        assert self.adapter.is_open_for_signup(signup_request) is False
        response = self.client.get(reverse("account_signup"))
        assert "Sign Up Closed" in response.content.decode("utf8")



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2017-05-21 04:23
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ("invitations", "0003_auto_20151126_1523"),
    ]

    operations = [
        migrations.CreateModel(
            name="ExampleSwappableInvitation",
            fields=[
                (
                    "invitation_ptr",
                    models.OneToOneField(
                        auto_created=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        primary_key=True,
                        serialize=False,
                        to="invitations.Invitation",
                    ),
                ),
                ("additonal_field", models.CharField(blank=True, max_length=255)),
            ],
            options={
                "abstract": False,
            },
            bases=("invitations.invitation",),
        ),
    ]



import datetime
import json
import re
from unittest.mock import patch

from django.test import Client
from django.test.client import RequestFactory
from django.test.utils import override_settings
from django.utils import timezone

try:
    from django.urls import reverse
except ImportError:
    from django.core.urlresolvers import reverse

import pytest
from django.contrib.auth.models import AnonymousUser
from django.core import mail
from freezegun import freeze_time

from invitations.adapters import BaseInvitationsAdapter, get_invitations_adapter
from invitations.app_settings import app_settings
from invitations.forms import InviteForm
from invitations.utils import get_invitation_model
from invitations.views import AcceptInvite, SendJSONInvite

Invitation = get_invitation_model()


class TestInvitationModel:
    @freeze_time("2015-07-30 12:00:06")
    def test_create_invitation(self, invitation_a):
        assert invitation_a.email == "email@example.com"
        assert invitation_a.key
        assert invitation_a.accepted is False
        assert invitation_a.created == timezone.now()

    def test_invitation_key_expiry(self, invitation_a):
        invitation_a.sent = timezone.now() - datetime.timedelta(
            days=app_settings.INVITATION_EXPIRY,
            minutes=1,
        )
        assert invitation_a.key_expired() is True

        invitation_a.sent = timezone.now() - datetime.timedelta(
            days=app_settings.INVITATION_EXPIRY,
            minutes=-1,
        )
        assert invitation_a.key_expired() is False


class TestInvitationsAdapter:
    def test_fetch_adapter(self):
        adapter = get_invitations_adapter()
        assert isinstance(adapter, BaseInvitationsAdapter)

    def test_email_subject_prefix_settings_with_site(self):
        adapter = get_invitations_adapter()
        result = adapter.format_email_subject("Bar", context={"site_name": "Foo.com"})
        assert result == "[Foo.com] Bar"

    @override_settings(INVITATIONS_EMAIL_SUBJECT_PREFIX="")
    def test_email_subject_prefix_settings_with_custom_override(self):
        adapter = get_invitations_adapter()
        result = adapter.format_email_subject("Bar", context={"site_name": "Foo.com"})
        assert result == "Bar"


class TestInvitationsSendView:
    client = Client()

    @pytest.mark.django_db
    def test_auth(self):
        response = self.client.post(
            reverse("invitations:send-invite"),
            {"email": "valid@example.com"},
            follow=True,
        )

        assert response.status_code == 404

    @pytest.mark.parametrize(
        "email, error",
        [
            ("invalid@example", "Enter a valid email address"),
            ("invited@example.com", "This e-mail address has already been"),
            ("flobble@example.com", "An active user is"),
        ],
    )
    def test_invalid_form_submissions(self, user_a, user_b, invitation_b, email, error):
        self.client.login(username="flibble", password="password")
        resp = self.client.post(reverse("invitations:send-invite"), {"email": email})

        form = resp.context_data["form"]
        assert error in form.errors["email"][0]

    @freeze_time("2015-07-30 12:00:06")
    def test_valid_form_submission(self, user_a):
        self.client.login(username="flibble", password="password")
        resp = self.client.post(
            reverse("invitations:send-invite"),
            {"email": "email@example.com"},
        )
        invitation = Invitation.objects.get(email="email@example.com")

        assert resp.status_code == 200
        assert "success_message" in resp.context_data.keys()

        assert invitation.sent == timezone.now()
        assert len(mail.outbox) == 1
        assert mail.outbox[0].to[0] == "email@example.com"
        assert "Invitation to join example.com" in mail.outbox[0].subject
        url = re.search(r"(?P<url>/invitations/[^\s]+)", mail.outbox[0].body).group(
            "url",
        )
        assert url == reverse(
            app_settings.CONFIRMATION_URL_NAME,
            kwargs={"key": invitation.key},
        )

    @override_settings(INVITATION_MODEL="ExampleSwappableInvitation")
    @freeze_time("2015-07-30 12:00:06")
    def test_valid_form_submission_with_swapped_model(self, user_a):
        self.client.login(username="flibble", password="password")
        resp = self.client.post(
            reverse("invitations:send-invite"),
            {"email": "email@example.com"},
        )
        invitation = Invitation.objects.get(email="email@example.com")

        assert resp.status_code == 200
        assert "success_message" in resp.context_data.keys()

        assert invitation.sent == timezone.now()
        assert len(mail.outbox) == 1
        assert mail.outbox[0].to[0] == "email@example.com"
        assert "Invitation to join example.com" in mail.outbox[0].subject
        url = re.search(r"(?P<url>/invitations/[^\s]+)", mail.outbox[0].body).group(
            "url",
        )
        assert url == reverse(
            app_settings.CONFIRMATION_URL_NAME,
            kwargs={"key": invitation.key},
        )


@pytest.mark.django_db
class TestInvitationsAcceptView:
    client = Client()

    def test_accept_invite_get_is_404(self, settings, invitation_b):
        settings.INVITATIONS_CONFIRM_INVITE_ON_GET = False
        resp = self.client.get(
            reverse(
                app_settings.CONFIRMATION_URL_NAME,
                kwargs={"key": invitation_b.key},
            ),
            follow=True,
        )
        assert resp.status_code == 404

    @pytest.mark.parametrize(
        "method",
        [
            ("get"),
            ("post"),
        ],
    )
    def test_accept_invite_invalid_key(self, method):
        client_with_method = getattr(self.client, method)
        resp = client_with_method(
            reverse(app_settings.CONFIRMATION_URL_NAME, kwargs={"key": "invalidKey"}),
            follow=True,
        )
        assert resp.status_code == 410

    @pytest.mark.parametrize(
        "method",
        [
            ("get"),
            ("post"),
        ],
    )
    def test_accept_invite_invalid_key_error_disabled(self, settings, method):
        settings.INVITATIONS_GONE_ON_ACCEPT_ERROR = False
        settings.INVITATIONS_LOGIN_REDIRECT = "/login-url/"
        client_with_method = getattr(self.client, method)
        resp = client_with_method(
            reverse(app_settings.CONFIRMATION_URL_NAME, kwargs={"key": "invalidKey"}),
            follow=True,
        )
        assert resp.request["PATH_INFO"] == "/login-url/"

    @pytest.mark.parametrize(
        "method",
        [
            ("get"),
            ("post"),
        ],
    )
    def test_accept_invite_accepted_key(self, accepted_invitation, method):
        client_with_method = getattr(self.client, method)
        resp = client_with_method(
            reverse(
                app_settings.CONFIRMATION_URL_NAME,
                kwargs={"key": accepted_invitation.key},
            ),
            follow=True,
        )
        assert resp.status_code == 410

    @pytest.mark.parametrize(
        "method",
        [
            ("get"),
            ("post"),
        ],
    )
    def test_accept_invite_accepted_key_error_disabled(
        self,
        settings,
        accepted_invitation,
        method,
    ):
        settings.INVITATIONS_GONE_ON_ACCEPT_ERROR = False
        settings.INVITATIONS_LOGIN_REDIRECT = "/login-url/"
        client_with_method = getattr(self.client, method)
        resp = client_with_method(
            reverse(
                app_settings.CONFIRMATION_URL_NAME,
                kwargs={"key": accepted_invitation.key},
            ),
            follow=True,
        )
        assert resp.request["PATH_INFO"] == "/login-url/"

    @pytest.mark.parametrize(
        "method",
        [
            ("get"),
            ("post"),
        ],
    )
    def test_accept_invite_expired_key(
        self,
        settings,
        sent_invitation_by_user_a,
        method,
    ):
        settings.INVITATIONS_INVITATION_EXPIRY = 0
        client_with_method = getattr(self.client, method)
        resp = client_with_method(
            reverse(
                app_settings.CONFIRMATION_URL_NAME,
                kwargs={"key": sent_invitation_by_user_a.key},
            ),
            follow=True,
        )
        assert resp.status_code == 410

    @pytest.mark.parametrize(
        "method",
        [
            ("get"),
            ("post"),
        ],
    )
    def test_accept_invite_expired_key_error_disabled(
        self,
        sent_invitation_by_user_a,
        method,
        settings,
    ):
        settings.INVITATIONS_INVITATION_EXPIRY = 0
        settings.INVITATIONS_GONE_ON_ACCEPT_ERROR = False
        settings.INVITATIONS_SIGNUP_REDIRECT = "/signup-url/"
        client_with_method = getattr(self.client, method)
        resp = client_with_method(
            reverse(
                app_settings.CONFIRMATION_URL_NAME,
                kwargs={"key": sent_invitation_by_user_a.key},
            ),
            follow=True,
        )
        assert resp.request["PATH_INFO"] == "/signup-url/"

    @pytest.mark.parametrize(
        "method",
        [
            ("get"),
            ("post"),
        ],
    )
    def test_accept_invite(self, settings, sent_invitation_by_user_a, user_a, method):
        settings.INVITATIONS_SIGNUP_REDIRECT = "/non-existent-url/"
        client_with_method = getattr(self.client, method)
        resp = client_with_method(
            reverse(
                app_settings.CONFIRMATION_URL_NAME,
                kwargs={"key": sent_invitation_by_user_a.key},
            ),
            follow=True,
        )
        invite = Invitation.objects.get(email="email@example.com")
        assert invite.accepted is True
        assert invite.inviter == user_a
        assert resp.request["PATH_INFO"] == "/non-existent-url/"

    def test_signup_redirect(self, settings, sent_invitation_by_user_a):
        settings.INVITATIONS_SIGNUP_REDIRECT = "/non-existent-url/"
        resp = self.client.post(
            reverse(
                app_settings.CONFIRMATION_URL_NAME,
                kwargs={"key": sent_invitation_by_user_a.key},
            ),
            follow=True,
        )
        invite = Invitation.objects.get(email="email@example.com")
        assert invite.accepted is True
        assert resp.request["PATH_INFO"] == "/non-existent-url/"


class TestInvitationSignals:
    client = Client()

    @patch("invitations.signals.invite_url_sent.send")
    def test_invite_url_sent_triggered_correctly(
        self,
        mock_signal,
        sent_invitation_by_user_a,
        user_a,
    ):
        invite_url = reverse(
            app_settings.CONFIRMATION_URL_NAME,
            args=[sent_invitation_by_user_a.key],
        )
        request = RequestFactory().get("/")
        invite_url = request.build_absolute_uri(invite_url)

        sent_invitation_by_user_a.send_invitation(request)

        assert mock_signal.called
        assert mock_signal.call_count == 1

        mock_signal.assert_called_with(
            instance=sent_invitation_by_user_a,
            invite_url_sent=invite_url,
            inviter=user_a,
            sender=Invitation,
        )

    @override_settings(INVITATIONS_SIGNUP_REDIRECT="/non-existent-url/")
    @patch("invitations.signals.invite_accepted.send")
    def test_invite_invite_accepted_triggered_correctly(
        self,
        mock_signal,
        sent_invitation_by_user_a,
    ):
        request = RequestFactory().get("/")
        sent_invitation_by_user_a.send_invitation(request)

        self.client.post(
            reverse(
                app_settings.CONFIRMATION_URL_NAME,
                kwargs={"key": sent_invitation_by_user_a.key},
            ),
            follow=True,
        )
        assert mock_signal.called
        assert mock_signal.call_count == 1

        assert mock_signal.call_args[1]["email"] == "email@example.com"
        assert mock_signal.call_args[1]["sender"] == AcceptInvite


class TestInvitationsForm:
    @pytest.mark.parametrize(
        "email, form_validity, errors",
        [
            ("bogger@example.com", True, None),
            ("accepted@example.com", False, "has already accepted an invite"),
            ("pending@example.com", False, "has already been invited"),
            ("flobble@example.com", False, "active user is using this"),
        ],
    )
    def test_form(
        self,
        email,
        form_validity,
        errors,
        accepted_invitation,
        pending_invitation,
        user_b,
    ):
        form = InviteForm(data={"email": email})
        if errors:
            assert errors in str(form.errors)
        else:
            assert form.errors == {}
        assert form.is_valid() is form_validity


@pytest.mark.django_db
class TestInvitationsManager:
    def test_managers(
        self,
        sent_invitation_by_user_a,
        accepted_invitation,
        expired_invitation,
        invitation_b,
    ):
        valid = Invitation.objects.all_valid().values_list("email", flat=True)
        expired = Invitation.objects.all_expired().values_list("email", flat=True)
        expected_valid = ["email@example.com", "invited@example.com"]
        expected_expired = ["accepted@example.com", "expired@example.com"]

        assert sorted(valid) == sorted(expected_valid)
        assert sorted(expired) == sorted(expected_expired)

    def test_delete_all(self):
        valid = Invitation.objects.all_valid().values_list("email", flat=True)
        Invitation.objects.delete_expired_confirmations()
        remaining_invites = Invitation.objects.all().values_list("email", flat=True)
        assert sorted(valid) == sorted(remaining_invites)


class TestInvitationsJSON:
    client = Client()

    @pytest.mark.parametrize(
        "data, expected, status_code",
        [
            (
                ["accepted@example.com"],
                {
                    "valid": [],
                    "invalid": [{"accepted@example.com": "already accepted"}],
                },
                400,
            ),
            (
                ["xample.com"],
                {"valid": [], "invalid": [{"xample.com": "invalid email"}]},
                400,
            ),
            ("xample.com", {"valid": [], "invalid": []}, 400),
            (
                ["pending@example.com"],
                {"valid": [], "invalid": [{"pending@example.com": "pending invite"}]},
                400,
            ),
            (
                ["flobble@example.com"],
                {
                    "valid": [],
                    "invalid": [{"flobble@example.com": "user registered email"}],
                },
                400,
            ),
            (
                ["example@example.com"],
                {"valid": [{"example@example.com": "invited"}], "invalid": []},
                201,
            ),
        ],
    )
    def test_post(
        self,
        settings,
        data,
        expected,
        status_code,
        user_a,
        accepted_invitation,
        pending_invitation,
        user_b,
    ):
        settings.INVITATIONS_ALLOW_JSON_INVITES = True
        self.client.login(username="flibble", password="password")
        response = self.client.post(
            reverse("invitations:send-json-invite"),
            data=json.dumps(data),
            content_type="application/json",
        )

        assert response.status_code == status_code
        assert json.loads(response.content.decode()) == expected

    def test_json_setting(self, user_a):
        self.client.login(username="flibble", password="password")
        response = self.client.post(
            reverse("invitations:send-json-invite"),
            data=json.dumps(["example@example.com"]),
            content_type="application/json",
        )

        assert response.status_code == 404

    @override_settings(INVITATIONS_ALLOW_JSON_INVITES=True)
    def test_anonymous_get(self):
        request = RequestFactory().get(
            reverse("invitations:send-json-invite"),
            content_type="application/json",
        )
        request.user = AnonymousUser()
        response = SendJSONInvite.as_view()(request)

        assert response.status_code == 302

    def test_authenticated_get(self, settings, user_a):
        settings.INVITATIONS_ALLOW_JSON_INVITES = True
        request = RequestFactory().get(
            reverse("invitations:send-json-invite"),
            content_type="application/json",
        )
        request.user = user_a
        response = SendJSONInvite.as_view()(request)

        assert response.status_code == 405


class TestInvitationsAdmin:
    client = Client()

    def test_admin_form_add(self, super_user):
        self.client.login(username="flibble", password="password")
        response = self.client.post(
            reverse("admin:invitations_invitation_add"),
            {"email": "valid@example.com", "inviter": super_user.id},
            follow=True,
        )
        invite = Invitation.objects.get(email="valid@example.com")

        assert response.status_code == 200
        assert invite.sent
        assert invite.inviter == super_user

    def test_admin_form_change(self, super_user, invitation_b):
        self.client.login(username="flibble", password="password")
        response = self.client.get(
            reverse("admin:invitations_invitation_change", args=(invitation_b.id,)),
            follow=True,
        )

        assert response.status_code == 200
        fields = list(response.context_data["adminform"].form.fields.keys())
        expected_fields = ["accepted", "key", "sent", "inviter", "email", "created"]
        assert fields == expected_fields



from test_settings import *  # noqa: F403

INSTALLED_APPS = (
    "django.contrib.auth",
    "django.contrib.admin",
    "django.contrib.contenttypes",
    "django.contrib.sessions",
    "django.contrib.sites",
    "django.contrib.messages",
    "allauth",
    "allauth.account",
    "allauth.socialaccount",
    "invitations",
    "tests",
)

AUTHENTICATION_BACKENDS = (
    "django.contrib.auth.backends.ModelBackend",
    "allauth.account.auth_backends.AuthenticationBackend",
)

ACCOUNT_ADAPTER = "invitations.models.InvitationsAdapter"

MIDDLEWARE.append("allauth.account.middleware.AccountMiddleware")  # noqa: F405



from django.conf import settings
from django.contrib import admin
from django.urls import include, path

admin.autodiscover()

urlpatterns = [
    path("invitations/", include("invitations.urls")),
    path("admin/", admin.site.urls),
]

if "allauth" in settings.INSTALLED_APPS:
    urlpatterns.append(path("accounts/", include("allauth.urls")))
